<?php

class DispletRetsIdxResidentials extends DispletRetsIdxPlugin{
	public function create_listing_variables($model, $is_single_listing = false, $include_phony = true){
		if (!empty($model['listings'])) {
			if (!empty($model['options']['results_limit']) && !$is_single_listing){
				$max_count = intval($model['options']['results_limit']);
				if ($model['meta']->last > $max_count) {
					$model['meta']->last = $max_count;
				}
				$limited_listings = array();
				$current_count = intval($model['meta']->first);
				$i = 0;
				foreach ($model['listings'] as $listing) {
					if (($current_count + $i) <= $max_count) {
						$limited_listings[] = $listing;
					}
					$i++;
				}
				$model['listings'] = $limited_listings;
			}
			$i = 1;
			if (!empty($model['is_mobile_search_results_page']) || !empty($model['is_mobile_property_details_page'])) {
				$property_details_page_url = home_url('rets-mobile');
			}
			else{
				$property_details_page_url = get_permalink($model['options']['property_details_page_id']);
			}
			foreach ($model['listings'] as $listing) {
				if ($model['is_displet_api']) {
					if (!empty($model['options']['address_format'])) {
						$listing->address = $model['options']['address_format'];
						$listing->address = str_replace('%%street_number%%', $listing->street_number, $listing->address);
						$listing->address = str_replace('%%street_name%%', $listing->street_name, $listing->address);
						$listing->address = str_replace('%%street_pre_direction%%', $listing->street_pre_direction, $listing->address);
						$listing->address = str_replace('%%street_post_direction%%', $listing->street_post_dir, $listing->address);
						$listing->address = str_replace('%%unit%%', $listing->unit, $listing->address);
						if (empty($listing->unit)) {
							$listing->address = str_replace('#', '', $listing->address);
						}
						$listing->address = trim($listing->address);
						$listing->address = str_replace('   ', ' ', $listing->address);
						$listing->address = str_replace('  ', ' ', $listing->address);
					}
					else{
						$listing->address = $listing->street_number . ' ' . $listing->street_pre_direction . ' '  . $listing->street_name . ' ' . $listing->street_post_dir;
						if (!empty($listing->unit)) {
							$listing->address .= ' #' . $listing->unit;
						}
						$listing->address = trim($listing->address);
						$listing->address = str_replace('  ', ' ', $listing->address);
					}
					$half_baths = (!empty($listing->half_baths)) ? '/' . $listing->half_baths : '';
					$listing->bathrooms = $listing->full_baths . $half_baths;
				}
				else{
					//$listing->id = $listing->id;
					$listing->list_price = $listing->attributes->price;
					$listing->address = $listing->location->address;
					$listing->city = $listing->location->name;
					$listing->state = $listing->location->state;
					$listing->zip = $listing->location->zip;
					$listing->num_bedrooms = $listing->attributes->bedrooms;
					$listing->bathrooms = $listing->attributes->bathrooms;
					$listing->square_feet = $listing->attributes->square_feet;
					$listing->property_type = str_replace('Houses', 'House', str_replace('Condos, Townhouses & Apts for Sale', 'Condo / Townhouse / Apt', $listing->category->name));
					$listing->mls_number = $listing->attributes->mls_id;
					$listing->internet_remarks = $listing->body;
					$listing->image_urls = new stdClass();
					$listing->image_urls->primary_big = $listing->images[0]->src;
					// Swap phones, emails and URLs from description
					if (!empty($listing->internet_remarks)) {
						$phone = '/([0-9]{3})[-. ]?([0-9]{4})/';
						$email = '/([\S]+)@([\S]+)/';
						$website = '/([\S]+)\.com([\S]+)/';
						$new_body = preg_replace($phone, 'XXX-XXXX', $listing->internet_remarks);
						$new_body = preg_replace($email, 'XXXX@XXXX', $new_body);
						$new_body = preg_replace($website, 'http://.com', $new_body);
						$listing->internet_remarks = $new_body;
					}
					if ($is_single_listing) {
						$listing->latitude = $listing->location->latitude;
						$listing->longitude = $listing->location->longitude;
						$listing->year_built = $listing->attributes->year;
						$listing->area_amenities = $listing->attributes->amenities;
						// Get largest of each photo
						if (is_array($listing->images)) {
							$images_array = array();
							// Get largest of each image
							for ($j = $i - 1; $j < count($listing->images); $j++) {
								if ($listing->images[$j]->num == $last_num || $j == count($listing->images) - 1) {
									$last_src = $listing->images[$j]->src;
								}
								if (($listing->images[$j]->num > $last_num || $j == count($listing->images) - 1) && !empty($last_src)) {
									$images_array[] = $last_src;
								}
								$last_num = $listing->images[$j]->num;
							}
							$listing->image_urls = new stdClass();
							$listing->image_urls->all_big = $images_array;
							$listing->image_urls->all_thumb = $images_array;
							$listing->image_urls->primary_big = $images_array[$i];
							$listing->image_urls->primary_thumb = $images_array[$i];
						}
					}
				}
				// Create permalink
				$permalink_state = (!empty($listing->state)) ? $listing->state : 'STATE';
				$permalink_city = (!empty($listing->city)) ? $listing->city : 'City';
				$permalink_zip = (!empty($listing->zip)) ? $listing->zip : '00000';
				$listing->permalink = self::get_permalink($property_details_page_url, $permalink_state, $permalink_city, $permalink_zip, $listing->id, $listing->address);
				if ($is_single_listing) {
					// Create maps from lat/long & address
					if ($listing->latitude && $listing->longitude && $listing->address && $listing->city && $listing->state) {
						$listing->maps = array(
							'map' => '<div id="displet-map-canvas"></div>',
							'street_view' => '<div id="displet-street-view-canvas"></div>'
						);
					}
					$listing->latitude_display = $listing->latitude;
					$listing->longitude_display = $listing->longitude;
					self::remove_unincluded_fields($listing, $model['options'], true);
					self::filter_fields($listing);
				}
				else{
					$listing->classes = new stdClass();
					if ($model['layout'] == 'table') {
						$listing->classes->table_view = 'displet-listing displet-listing-' . $i . ' displet-showing displet-current';
					}
					else{
						$listing->classes->gallery_view = 'displet-listing displet-listing-' . $i . ' displet-showing';
						$listing->classes->list_view = 'displet-listing displet-listing-' . $i . ' displet-showing';
					}
					if ($model['options']['listings_orientation'] == 'gallery' && !$model['is_mobile_search_results_page']){
						$listing->classes->gallery_view .= ' displet-current';
					}
					else if ($model['options']['listings_orientation'] == 'list' || ($model['is_mobile_search_results_page'] && $model['options']['listings_orientation'] != 'map')) {
						$listing->classes->list_view .= ' displet-current';
					}
					self::remove_unincluded_fields($listing, $model['options'], false);
				}
				$i++;
			}
		}
		else{
			$i = 1;
		}
		if (!$is_single_listing && $include_phony) {
			$listings_per_page = intval($model['options']['listings_per_page']);
			if ($i <= $listings_per_page) {
				for ($j = $i; $j <= $listings_per_page; $j++) {
					$phony_listing = new stdClass();
					$phony_listing->classes = new stdClass();
					if ($model['layout'] == 'table') {
						$phony_listing->classes->table_view = 'displet-listing displet-listing-' . $j . ' displet-hiding displet-current';
					}
					else{
						$phony_listing->classes->gallery_view = 'displet-listing displet-listing-' . $j . ' displet-hiding';
						$phony_listing->classes->list_view = 'displet-listing displet-listing-' . $j . ' displet-hiding';
					}
					if ($model['options']['listings_orientation'] == 'gallery'){
						$phony_listing->classes->gallery_view .= ' displet-current';
					}
					else if ($model['options']['listings_orientation'] == 'list') {
						$phony_listing->classes->list_view .= ' displet-current';
					}
					$model['listings'][] = $phony_listing;
				}
			}
		}
		if (!$is_single_listing) {
			$model = self::get_listings_pagination($model);
		}
		return $model;
	}

	private function remove_unincluded_fields($listing, $options, $is_single_listing){
		if ($is_single_listing) {
			$option_name_listing_field_pairs = array(
				'include_modified' => 'modified',
				'include_list_date' => 'list_date',
				'include_listing_office_pdp' => 'listing_office_name',
				'include_listing_agent_pdp' => 'listing_agent_name',
				'include_listing_agent_id' => 'listing_agent_id',
				'include_listing_office_id' => 'listing_office_id',
				'include_foreclosure' => 'is_foreclosure',
				'include_short_sale' => 'short_sale',
				'include_longitude' => 'longitude_display',
				'include_latitude' => 'latitude_display',
				'include_feed_image_trans_date' => 'feed_image_trans_date',
				'include_sysid' => 'sysid',
				'include_price_per_square_feet' => 'price_per_sq_feet'
			);
		}
		else {
			$option_name_listing_field_pairs = array(
				'include_listing_agent' => 'listing_agent_name',
				'include_listing_office' => 'listing_office_name',
			);
		}
		foreach ($option_name_listing_field_pairs as $option_name => $field) {
			if (empty($options[$option_name])) {
				unset($listing->{$field});
			}
		}
	}

	private function filter_fields($listing){
		$ugly_fields = array(
			'area_amenities',
			'appliances_equipment',
			'basement_description',
			'den_description',
			'dining_description',
			'family_room_description',
			'fireplace_description',
			'floor',
			'garage_description',
			'interior_features',
			'laundry_location',
			'living_description',
			'rooms',
			'exterior_features',
			'fence_description',
			'lot_description',
			'parking_description',
			'pool_description',
			'waterfront_description',
			'area_amenities',
			'green_features'
		);
		foreach ($ugly_fields as $field) {
			if (!empty($listing->{$field})) {
				$listing->{$field} = DispletRetsIdxUtilities::add_spaces_after_commas($listing->{$field});
			}
		}
	}

	public function get_permalink($base_url, $state = false, $city = false, $zip = false, $id = false, $address = false){
		if (!empty($base_url)) {
			$link = rtrim($base_url, '/') . '/';
			if (!empty($state)) {
				$link .= preg_replace('/[^\w-]+/', '', preg_replace('/[ ]+/', '-', $state)) . '/';
			}
			if (!empty($city)) {
				$link .= preg_replace('/[^\w-]+/', '', preg_replace('/[ ]+/', '-', $city)) . '/';
			}
			if (!empty($zip)) {
				$link .= preg_replace('/[^\w-]+/', '', preg_replace('/[ ]+/', '-', $zip)) . '/';
			}
			if (!empty($id)) {
				$link .= $id . '/';
			}
			if (!empty($address)) {
				$link .= preg_replace('/[^\w-]+/', '', preg_replace('/[ ]+/', '-', $address));
			}
			return $link;
		}
	}

	public function get_field_values($field, $api_key){
		$query_url = parent::$api_url . '/residentials/field_options?field=' . $field . '&authentication_token=' . $api_key;
		$query_args = array(
			'timeout' => 10,
			'headers' => array(
				'referer' => home_url()
			)
		);
		$json_array = wp_remote_get($query_url, $query_args);
		if (is_array($json_array)) {
			$json_data = json_decode($json_array['body']);
			return $json_data->field_options;
		}
	}

	public function get_listing($model, $retry_with_sysid = false) {
		if ($model['is_displet_api']) {
			if ($retry_with_sysid) {
				$query_url = parent::$api_url . '/residentials/search?authentication_token=' . $model['options']['displet_app_key'] . '&sysid=' . $model['property_id'];
			}
			else{
				$query_url = parent::$api_url . '/residentials/search?authentication_token=' . $model['options']['displet_app_key'] . '&id=' . $model['property_id'];
			}
			if (!empty($model['return_fields'])) {
				$query_url .= '&return_fields=' . $model['return_fields'];
			}
			$query_args = array(
				'timeout' => 10,
				'headers' => array(
					'referer' => home_url()
				)
			);
			$json_array = wp_remote_get($query_url, $query_args);
		}
		else{
			$json_array = wp_remote_get('http://api.oodle.com/api/v2/listings?key=579B95506556&format=json&jsoncallback=none&region=usa&q=' . $model['property_id']);
		}
		if (is_array($json_array)) {
			$json_data = json_decode($json_array['body']);
			if ($model['is_displet_api']) {
				if (!empty($json_data->results)) {
					$model['listings'] = $json_data->results;
				}
			}
			else {
				if (!empty($json_data->listings)) {
					$model['listings'] = $json_data->listings;
				}
			}
		}
		$model = self::create_listing_variables($model, true);
		return $model;
	}

	public function get_agent_id_ajax(){
		check_ajax_referer('displet_get_agent_id_nonce');
		if (isset($_POST['action']) && $_POST['action'] == 'displet_get_agent_id_request' && !empty($_POST['mls_number'])){
			$model = DispletRetsIdxModel::get_model();
			$model['return_fields'] = 'listing_agent_id';
			$model['mls_number'] = $_POST['mls_number'];
			$results = DispletRetsIdxResidentialsApi::get_listings($model, false);
			if (!empty($results['listings'][0]->listing_agent_id)) {
				echo $results['listings'][0]->listing_agent_id;
				die();
			}
		}
		echo 'Failed';
		die();
	}

	public function get_office_id_ajax(){
		check_ajax_referer('displet_get_office_id_nonce');
		if (isset($_POST['action']) && $_POST['action'] == 'displet_get_office_id_request' && !empty($_POST['mls_number'])){
			$model = DispletRetsIdxModel::get_model();
			$model['return_fields'] = 'listing_office_id';
			$model['mls_number'] = $_POST['mls_number'];
			$results = DispletRetsIdxResidentialsApi::get_listings($model, false);
			if (!empty($results['listings'][0]->listing_office_id)) {
				echo $results['listings'][0]->listing_office_id;
				die();
			}
		}
		echo 'Failed';
		die();
	}

	public function get_return_fields($model){
		$return_fields = 'city,full_baths,half_baths,id,internet_remarks,latitude,list_price,longitude,num_bedrooms,primary_big_image_urls,property_type,square_feet,state,status,street_name,street_number,street_post_dir,street_pre_direction,unit,zip';
		if (!empty($model['options']['include_subdivision'])) {
			$return_fields .= ',subdivision';
		}
		if (!empty($model['options']['include_mls_number'])) {
			$return_fields .= ',mls_number';
		}
		if (!empty($model['options']['include_listing_agent'])) {
			// address_internet added as substitute for listing_agent_email for RAPB DPC
			$return_fields .= ',listing_agent_name,address_internet';
		}
		if (!empty($model['options']['include_listing_office'])) {
			$return_fields .= ',listing_office_name';
		}
		if ($model['layout'] == 'table') {
			$return_fields .= ',year_built';
		}
		return $return_fields;
	}

	public function get_listings_pagination($model){
		$page_url = rtrim(get_permalink(), '/');
		if ($model['meta']->count == $model['meta']->last) {
			$last_page_of_listings = floor(intval($model['meta']->count) / intval($model['listings_per_page']));
			if (!empty($last_page_of_listings)) {
				$model['previous_page_url'] = $page_url . '/page/' . $last_page_of_listings;
			}
			else{
				$model['previous_page_url'] = $page_url;
			}
			$model['next_page_url'] = $page_url . '/#next';
		}
		else if ($model['page_id']) {
			$next_page_id = $model['page_id'] + 1;
			$previous_page_id = $model['page_id'] - 1;
			if ($model['page_id'] < 2) {
				$previous_page = '/#previous';
			}
			else{
				$previous_page = '/page/' . $previous_page_id;
			}
			$next_page = '/page/' . $next_page_id;
			$model['previous_page_url'] = $page_url . $previous_page;
			$model['next_page_url'] = $page_url . $next_page;
		}
		else{
			$model['previous_page_url'] = $page_url . '/#previous';
			$model['next_page_url'] = $page_url . '/page/2';
		}
		return $model;
	}

	public function get_shortcode_translations($include_property_filter_shortcodes = true){
		$shortcode_translations = array(
			'minacres' => 'min_acres',
			'minbathrooms' => 'min_bathrooms',
			'minbedrooms' => 'min_bedrooms',
			'minlistprice' => 'min_list_price', 
			'minsquarefeet' => 'min_square_feet',
			'minstories' => 'min_stories',
			'maxbathrooms' => 'max_bathrooms',
			'maxbedrooms' => 'max_bedrooms',
			'maxlistprice' => 'max_list_price',
			'maxsquarefeet' => 'max_square_feet',
			'yearbuilt' => 'year_built',
		);
		$no_translations = array(
			'area_mls_defined',
			'basement',
			'city',
			'county',
			'direction',
			'is_foreclosure',
			'is_gated_community',
			'keyword',
			'last_modified',
			'listed_since',
			'listing_agent_id',
			'listing_office_id',
			'master_on_main',
			'max_price_per_sq_feet',
			'max_sold_date',
			'max_square_feet_available',
			'min_lot_size',
			'min_price_per_sq_feet',
			'min_sold_date',
			'min_square_feet_available',
			'mls_number',
			'pool_on_property', 
			'property_type',
			'quick_terms',
			'school',
			'school_district',
			'short_sale',
			'sort_by',
			'status',
			'street_name',
			'street_number',
			'subdivision',
			'waterfront',
			'zip',
		);
		foreach ($no_translations as $key_and_value) {
			$shortcode_translations[$key_and_value] = $key_and_value;
		}
		if ($include_property_filter_shortcodes) {
			// Remove because using after initial foreach due to property filter possibility
			$keys_to_remove = array(
				'minlistprice',
				'maxlistprice',
				'city',
				'property_type',
				'zip'
			);
			foreach ($keys_to_remove as $key) {
				unset($shortcode_translations[$key]);
			}
		}
		return $shortcode_translations;
	}
}

add_action('wp_ajax_displet_get_agent_id_request', array('DispletRetsIdxResidentials', 'get_agent_id_ajax'));
add_action('wp_ajax_nopriv_displet_get_agent_id_request', array('DispletRetsIdxResidentials', 'get_agent_id_ajax'));
add_action('wp_ajax_displet_get_office_id_request', array('DispletRetsIdxResidentials', 'get_office_id_ajax'));
add_action('wp_ajax_nopriv_displet_get_office_id_request', array('DispletRetsIdxResidentials', 'get_office_id_ajax'));

?>