<?php

/**
 * Functions below permitted for use in external applications (custom templates, custom theme functionality, etc.)
 * 
 * All function names, parameters, and return types/values are to remain unchanged
 */

/*****************************
/ General
*****************************/

/**
 * @param: $filename: string (without .php)
 * @return: print: include
 */
function displetretsidx_get_template_part($filename){
	include(DispletRetsIdxLoad::get_template_path($filename . '.php'));
}

/**
 * @param: $model: variable $model passed to template
 * @return: print: commented HTML markup
 */
function displetretsidx_setup_template_data($model){
	global $displetretsidx_template;
	$displetretsidx_template = $model;
	if (!empty($displetretsidx_template['query_url'])) {
		echo '<!-- Displet Query: ' . $displetretsidx_template['query_url'] . ' -->';
	}
}

/**
 * @package: displetretsidx_setup_template_data($model)
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_color_scheme_class(){
	global $displetretsidx_template;
	echo 'displet-' . $displetretsidx_template['options']['color_scheme'] . '-color-scheme';
}

/**
 * @package: displetretsidx_setup_template_data($model)
 * @param: none
 * @return: boolean
 */
function displetretsidx_has_api_key(){
	global $displetretsidx_template;
	if (!empty($displetretsidx_template['is_displet_api'])) {
		return true;
	}
	return false;
}

/**
 * @package: displetretsidx_setup_template_data($model)
 * @param: none
 * @return: boolean
 */
function displetretsidx_has_disclaimer(){
	global $displetretsidx_template;
	if (!empty($displetretsidx_template['options']['disclaimer'])) {
		return true;
	}
	return false;
}

/**
 * @package: displetretsidx_setup_template_data($model)
 * @param: none
 * @return: print: text
 */
function displetretsidx_the_disclaimer(){
	global $displetretsidx_template;
	echo $displetretsidx_template['options']['disclaimer'];
}

/**
 * @package: displetretsidx_setup_template_data($model)
 * @param: none
 * @return: print: HTML markup
 */
function displetretsidx_the_credit(){
	global $displetretsidx_template;
	$credit = 'Powered by ';
	if (!empty($displetretsidx_template['options']['no_link'])) {	
		$credit .= 'Displet Real Estate Search';
	}
	else{
		$credit .= '<a href="http://displet.com/wordpress-plugins/displet-rets-idx-plugin/" target="_blank">Displet Real Estate Search</a>';
	}
	echo $credit;
}

/*****************************
/ For listings templates (displet-dynamic.php)
*****************************/

/**
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_first_count_class(){
	echo 'displet-first-listings-value';
}

/**
 * @package: displetretsidx_setup_template_data($model)
 * @param: none
 * @return: print: text
 */
function displetretsidx_the_first_count(){
	global $displetretsidx_template;
	echo number_format($displetretsidx_template['meta']->first);
}

/**
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_last_count_class(){
	echo 'displet-last-listings-value';
}

/**
 * @package: displetretsidx_setup_template_data($model)
 * @param: none
 * @return: print: text
 */
function displetretsidx_the_last_count(){
	global $displetretsidx_template;
	echo number_format($displetretsidx_template['meta']->last);
}

/**
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_total_count_class(){
	echo 'displet-total-listings-value';
}

/**
 * @package: displetretsidx_setup_template_data($model)
 * @param: none
 * @return: print: text
 */
function displetretsidx_the_total_count(){
	global $displetretsidx_template;
	echo number_format($displetretsidx_template['meta']->count);
}

/**
 * @package: displetretsidx_setup_template_data($model)
 * @param: none
 * @return: print: url
 */
function displetretsidx_the_previous_page_url(){
	global $displetretsidx_template;
	echo $displetretsidx_template['previous_page_url'];
}

/**
 * @package: displetretsidx_setup_template_data($model)
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_previous_page_class(){
	global $displetretsidx_template;
	$class = 'displet-previous-listings-link';
	if (!is_paged()){
		$class .= ' displet-none';
	}
	echo $class;
}

/**
 * @package: displetretsidx_setup_template_data($model)
 * @param: none
 * @return: print: url
 */
function displetretsidx_the_next_page_url(){
	global $displetretsidx_template;
	echo $displetretsidx_template['next_page_url'];
}

/**
 * @package: displetretsidx_setup_template_data($model)
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_next_page_class(){
	global $displetretsidx_template;
	$class = 'displet-next-listings-link';
	if (intval($displetretsidx_template['meta']->count) == intval($displetretsidx_template['meta']->last)){
		$class .= ' displet-none';
	}
	echo $class;
}

/**
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_sort_class(){
	echo 'displet-listings-sortby';
}

/**
 * @package: displetretsidx_setup_template_data($model)
 * @param: none
 * @return: print: HTML markup
 */
function displetretsidx_the_sort_options(){
	global $displetretsidx_template;
	echo $displetretsidx_template['sort_options'];
}

/**
 * @package: displetretsidx_setup_template_data($model)
 * @param: none
 * @return: boolean
 */
function displetretsidx_have_listings(){
	global $displetretsidx_template;
	if (empty($displetretsidx_template['array_index'])) {
		$displetretsidx_template['array_index'] = 0;
	}
	if (!empty($displetretsidx_template['listings'][$displetretsidx_template['array_index']])) {
		return true;
	}
	return false;
}

/**
 * @package: displetretsidx_setup_template_data($model)
 * @param: none
 * @return: none
 */
function displetretsidx_the_listing(){
	global $displetretsidx_template;
	global $displetretsidx_listing;
	$displetretsidx_listing = $displetretsidx_template['listings'][$displetretsidx_template['array_index']];
	$displetretsidx_template['array_index']++;
}

/**
 * @param: $listing: variable from foreach ($model['listings'] as $listing)
 * @return: none
 */
function displetretsidx_setup_listing_data($listing){
	global $displetretsidx_listing;
	$displetretsidx_listing = $listing;
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: url
 */
function displetretsidx_the_permalink(){
	global $displetretsidx_listing;
	echo $displetretsidx_listing->permalink;
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: text
 */
function displetretsidx_the_price(){
	global $displetretsidx_listing;
	echo number_format($displetretsidx_listing->list_price);
}

/**
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_price_class(){
	echo 'displet-price-value';
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_price_container_class(){
	global $displetretsidx_listing;
	$class = 'displet-price';
	if (empty($displetretsidx_listing->list_price)) {
		$class .= ' displet-none';
	}
	echo $class;
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: boolean
 */
function displetretsidx_has_photo_url(){
	global $displetretsidx_listing;
	if (!empty($displetretsidx_listing->image_urls->primary_big)) {
		return true;
	}
	return false;
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: url
 */
function displetretsidx_get_photo_url(){
	global $displetretsidx_listing;
	return $displetretsidx_listing->image_urls->primary_big;
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: url
 */
function displetretsidx_the_photo_url(){
	global $displetretsidx_listing;
	echo $displetretsidx_listing->image_urls->primary_big;
}


/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: CSS style
 */
function displetretsidx_the_photo_style(){
	global $displetretsidx_listing;
	if (!empty($displetretsidx_listing->image_urls->primary_big)) {
		echo 'background-image: url(' . $displetretsidx_listing->image_urls->primary_big . ');';
	}
}

/**
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_photo_class(){
	echo 'displet-image-value';
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_photo_container_class(){
	global $displetretsidx_listing;
	$class = 'displet-image';
	if (empty($displetretsidx_listing->image_urls->primary_big)){
		$class .= ' displet-none';
	}
	echo $class;
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: text
 */
function displetretsidx_the_address(){
	global $displetretsidx_listing;
	echo $displetretsidx_listing->address;
}

/**
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_address_class(){
	echo 'displet-address-value';
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_address_container_class(){
	global $displetretsidx_listing;
	$class = 'displet-address';
	if (empty($displetretsidx_listing->address)){
		$class .= ' displet-none';
	}
	echo $class;
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: text
 */
function displetretsidx_the_city(){
	global $displetretsidx_listing;
	echo $displetretsidx_listing->city;
}

/**
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_city_class(){
	echo 'displet-city-value';
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_city_container_class(){
	global $displetretsidx_listing;
	$class = 'displet-city';
	if (empty($displetretsidx_listing->city)) {
		$class .= ' displet-none';
	}
	echo $class;
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: text
 */
function displetretsidx_the_state(){
	global $displetretsidx_listing;
	echo $displetretsidx_listing->state;
}

/**
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_state_class(){
	echo 'displet-state-value';
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_state_container_class(){
	global $displetretsidx_listing;
	$class = 'displet-state';
	if (empty($displetretsidx_listing->state)) {
		$class .= ' displet-none';
	}
	echo $class;
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: text
 */
function displetretsidx_the_zip(){
	global $displetretsidx_listing;
	echo $displetretsidx_listing->zip;
}

/**
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_zip_class(){
	echo 'displet-zip-value';
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_zip_container_class(){
	global $displetretsidx_listing;
	$class = 'displet-zip';
	if (empty($displetretsidx_listing->zip)) {
		$class .= ' displet-none';
	}
	echo $class;
}

/**
 * @package: displetretsidx_setup_template_data($model)
 * @param: none
 * @return: boolean
 */
function displetretsidx_use_subdivision(){
	global $displetretsidx_template;
	if (!empty($displetretsidx_template['options']['include_subdivision'])) {
		return true;
	}
	return false;
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: text
 */
function displetretsidx_the_subdivision(){
	global $displetretsidx_listing;
	echo $displetretsidx_listing->subdivision;
}

/**
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_subdivision_class(){
	echo 'displet-subdivision-value';
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_subdivision_container_class(){
	global $displetretsidx_listing;
	$class = 'displet-subdivision';
	if (empty($displetretsidx_listing->subdivision)) {
		$class .= ' displet-none';
	}
	echo $class;
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: text
 */
function displetretsidx_the_bedrooms(){
	global $displetretsidx_listing;
	echo $displetretsidx_listing->num_bedrooms;
}

/**
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_bedrooms_class(){
	echo 'displet-beds-value';
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_bedrooms_container_class(){
	global $displetretsidx_listing;
	$class = 'displet-beds';
	if (empty($displetretsidx_listing->num_bedrooms)) {
		$class .= ' displet-none';
	}
	echo $class;
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: text
 */
function displetretsidx_the_bathrooms(){
	global $displetretsidx_listing;
	echo $displetretsidx_listing->bathrooms;
}

/**
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_bathrooms_class(){
	echo 'displet-baths-value';
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_bathrooms_container_class(){
	global $displetretsidx_listing;
	$class = 'displet-baths';
	if (empty($displetretsidx_listing->bathrooms)) {
		$class .= ' displet-none';
	}
	echo $class;
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: text
 */
function displetretsidx_the_square_feet(){
	global $displetretsidx_listing;
	echo number_format($displetretsidx_listing->square_feet);
}

/**
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_square_feet_class(){
	echo 'displet-square-feet-value';
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_square_feet_container_class(){
	global $displetretsidx_listing;
	$class = 'displet-square-feet';
	if (empty($displetretsidx_listing->square_feet)) {
		$class .= ' displet-none';
	}
	echo $class;
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: text
 */
function displetretsidx_the_property_type(){
	global $displetretsidx_listing;
	echo $displetretsidx_listing->property_type;
}

/**
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_property_type_class(){
	echo 'displet-property-type-value';
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_property_type_container_class(){
	global $displetretsidx_listing;
	$class = 'displet-property-type';
	if (empty($displetretsidx_listing->property_type)) {
		$class .= ' displet-none';
	}
	echo $class;
}

/**
 * @package: displetretsidx_setup_template_data($model)
 * @param: none
 * @return: boolean
 */
function displetretsidx_use_mls_number(){
	global $displetretsidx_template;
	if (!empty($displetretsidx_template['options']['include_mls_number'])) {
		return true;
	}
	return false;
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: text
 */
function displetretsidx_the_mls_number(){
	global $displetretsidx_listing;
	echo $displetretsidx_listing->mls_number;
}

/**
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_mls_number_class(){
	echo 'displet-mls-value';
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_mls_number_container_class(){
	global $displetretsidx_listing;
	$class = 'displet-mls';
	if (empty($displetretsidx_listing->mls_number)) {
		$class .= ' displet-none';
	}
	echo $class;
}

/**
 * @package: displetretsidx_setup_template_data($model)
 * @param: none
 * @return: boolean
 */
function displetretsidx_use_listing_agent(){
	global $displetretsidx_template;
	if (!empty($displetretsidx_template['options']['include_listing_agent'])) {
		return true;
	}
	return false;
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: text
 */
function displetretsidx_the_listing_agent(){
	global $displetretsidx_listing;
	$agent = $displetretsidx_listing->listing_agent_name;
	if (!empty($displetretsidx_listing->listing_agent_name) && !empty($displetretsidx_listing->listing_office_name)) {
		$agent .= ',';
	}
	echo $agent;
}

/**
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_listing_agent_class(){
	echo 'displet-listing-agent-name-value';
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_listing_agent_container_class(){
	global $displetretsidx_listing;
	$class = 'displet-listing-agent-name';
	if (empty($displetretsidx_listing->listing_agent_name)) {
		$class .= ' displet-none';
	}
	echo $class;
}

/**
 * @package: displetretsidx_setup_template_data($model)
 * @param: none
 * @return: boolean
 */
function displetretsidx_use_listing_office(){
	global $displetretsidx_template;
	if (!empty($displetretsidx_template['options']['include_listing_office'])) {
		return true;
	}
	return false;
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: text
 */
function displetretsidx_the_listing_office(){
	global $displetretsidx_listing;
	echo $displetretsidx_listing->listing_office_name;
}

/**
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_listing_office_class(){
	echo 'displet-listing-office-name-value';
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_listing_office_container_class(){
	global $displetretsidx_listing;
	$class = 'displet-listing-office-name';
	if (empty($displetretsidx_listing->listing_office_name)) {
		$class .= ' displet-none';
	}
	echo $class;
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: text
 */
function displetretsidx_the_description(){
	global $displetretsidx_listing;
	echo $displetretsidx_listing->internet_remarks;
}

/**
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_description_class(){
	echo 'displet-description-value';
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_description_container_class(){
	global $displetretsidx_listing;
	$class = 'displet-description';
	if (empty($displetretsidx_listing->internet_remarks)) {
		$class .= ' displet-none';
	}
	echo $class;
}

/**
 * @package: displetretsidx_setup_template_data($model)
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_no_results_class(){
	global $displetretsidx_template;
	$class = 'displet-no-results';
	if (!empty($displetretsidx_template['listings'])) {
		$class .= ' displet-none';
	}
	echo $class;
}

/**
 * @package: displetretsidx_setup_template_data($model)
 * @param: none
 * @return: boolean
 */
function displetretsidx_use_results_limit_message(){
	global $displetretsidx_template;
	if (!empty($displetretsidx_template['results_limit_message'])) {
		return true;
	}
	return false;
}

/**
 * @package: displetretsidx_setup_template_data($model)
 * @param: none
 * @return: boolean
 */
function displetretsidx_the_results_limit_message(){
	global $displetretsidx_template;
	echo $displetretsidx_template['results_limit_message'];
}

/**
 * @package: displetretsidx_setup_template_data($model)
 * @param: none
 * @return: boolean
 */
function displetretsidx_use_disclaimer_image(){
	global $displetretsidx_template;
	if (!empty($displetretsidx_template['options']['disclaimer_image']) && !empty($displetretsidx_template['options']['include_disclaimer_image'])) {
		return true;
	}
	return false;
}


/**
 * @package: displetretsidx_setup_template_data($model)
 * @param: none
 * @return: print: url
 */
function displetretsidx_the_disclaimer_image_url(){
	global $displetretsidx_template;
	echo $displetretsidx_template['options']['disclaimer_image'];
}

/**
 * @param: none
 * @return: print: HTML markup
 */
function displetretsidx_the_listings_loading_container(){
	echo '<div class="displet-listings-loading displet-none"></div>';
}

/**
 * @param: none
 * @return: print: HTML markup
 */
function displetretsidx_the_unavailable_listing_container(){
	echo '<div class="displet-unavailable"></div>';
}

/*****************************
/ For displet-dynamic.php only
*****************************/

/**
 * @package: displetretsidx_setup_template_data($model)
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_gallery_view_class(){
	global $displetretsidx_template;
	$class = 'displet-tile-view';
	if ($displetretsidx_template['orientation'] == 'gallery'){
		$class .= ' displet-current-view';
	}
	echo $class;
}

/**
 * @package: displetretsidx_setup_template_data($model)
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_list_view_class(){
	global $displetretsidx_template;
	$class = 'displet-list-view';
	if ($displetretsidx_template['orientation'] == 'list'){
		$class .= ' displet-current-view';
	}
	echo $class;
}

/**
 * @package: displetretsidx_setup_template_data($model)
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_map_view_class(){
	global $displetretsidx_template;
	$class = 'displet-map-view';
	if ($displetretsidx_template['orientation'] == 'map'){
		$class .= ' displet-current-view';
	}
	echo $class;
}

/**
 * @package: displetretsidx_setup_template_data($model)
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_gallery_listing_class(){
	global $displetretsidx_template;
	global $displetretsidx_listing;
	$class = 'displet-tile-listing ' . $displetretsidx_listing->classes->gallery_view;
	if ($displetretsidx_template['options']['listings_orientation'] != 'gallery'){
		$class .= ' displet-none';
	}
	echo $class;
}

/**
 * @package: displetretsidx_setup_template_data($model)
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_list_listing_class(){
	global $displetretsidx_template;
	global $displetretsidx_listing;
	$class = 'displet-vertical-listing ' . $displetretsidx_listing->classes->list_view;
	if ($displetretsidx_template['options']['listings_orientation'] != 'list'){
		$class .= ' displet-none';
	}
	echo $class;
}

/**
 * @param: none
 * @return: print: HTML markup
 */
function displetretsidx_the_hover_transition_element(){
	echo '<div class="displet-hovertrans"></div>';
}

/**
 * @param: none
 * @return: print: HTML markup
 */
function displetretsidx_the_hover_transition_overlay_element(){
	echo '<div class="displet-text-overlay"></div><div class="displet-text-overlay-hovertrans"></div>';
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_under_contract_banner_class(){
	global $displetretsidx_listing;
	$class = 'displet-under-contract';
	if (stripos($displetretsidx_listing->status, 'pen') === false && stripos($displetretsidx_listing->status, 'und') === false){
		$class .= ' displet-none';
	}
	echo $class;
}

/**
 * @package: displetretsidx_the_listing() or displetretsidx_setup_listing_data($listing)
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_contingency_banner_class(){
	global $displetretsidx_listing;
	$class = 'displet-contingency';
	if (stripos($displetretsidx_listing->status, 'conting') === false){
		$class .= ' displet-none';
	}
	echo $class;
}

/**
 * @param: none
 * @return: print: HTML markup
 */
function displetretsidx_the_map(){
	echo
		'<script type="text/javascript" src="http://maps.google.com/maps/api/js?sensor=false"></script>
		<div id="displetretsidx_canvas" style="width: 100%; height: 500px;"></div>';
}

/**
 * @package: displetretsidx_setup_template_data($model)
 * @param: none
 * @return: print: CSS classname
 */
function displetretsidx_the_map_class(){
	global $displetretsidx_template;
	if ($displetretsidx_template['orientation'] != 'map'){
		echo 'hiding';
	}
}

?>